# CultivatedRabbit

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'cultivated_rabbit'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install cultivated_rabbit

## Usage

Used as a wrapper for rabbit, config based.

The config is based on a yml file.

Imagine you have a config file located at: `some_project/config/rabbit_config.yml`

```yml
---
rabbit_mq:
  connection_string: amqp://rabbit:5672
  queue_names:  # Queue names object can have any valid bunny params. http://rubybunny.info/articles/queues.html
    - publish: foo
      subscribe: bar
      durable: true
      auto_delete: false
      exchange_name: foobar
      exclusive: false
    - publish: hello

```

You can use this config like so:

```ruby
require 'cultivated_rabbit'

callback = Proc.new do |body, rabbit| # body is the rabbit message body, rabbit is the rabbit wrapper in case you would like to publish another message. rabbi.publish(queue_name -> optional will read publish from config)
  puts body
  puts rabbit
  rabbit.publish(message: 'hello world')
  rabbit.publish(queue_name: 'some_queue', message: 'bye world')
end

CultivatedRabbit.load_from_config(
  config_path: 'some_project/config/rabbit_config.yml',
  sub_proc: callback
  )

loop { sleep 5 }

```

It can also be used without a config by caling `CultivatedRabbit.rabbit_wrapper` this will return the rabbit_wrapper class passed to the proc.

```ruby
require 'cultivated_rabbit'

rabbit_wrapper = CultivatedRabbit.rabbit_wrapper.new(connection_string: 'amqp://localhost:1567', exchange_name: 'default', config: nil) # You can also pass in a config here
rabbit_wrapper.publish('some_queue_name') do |body|
  puts body
  rabbit_wrapper.publish(queue_name: 'some_queue', message: 'hello world')
end

loop { sleep 5 }

```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/[USERNAME]/cultivated_rabbit. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the CultivatedRabbit project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/[USERNAME]/cultivated_rabbit/blob/master/CODE_OF_CONDUCT.md).
